-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

ConfigurationHelper = class();
ConfigurationHelper.HEALTH = 1;
ConfigurationHelper.POWER = 11;

ConfigurationHelper.CTRL = 3;
ConfigurationHelper.ALT = 4;
ConfigurationHelper.SHIFT = 5;

function ConfigurationHelper:Constructor()
	self.level = player:GetLevel();
	self.registeredBars = 1;
end

function ConfigurationHelper:RegisterBarCreator( description, barname, callback, disable )
	if ( self.RegisteredEasyBars == nil ) then
		self.RegisteredEasyBars = { };
	end
	if ( self.RegisteredEasyBars[description] == nil ) then
		self.RegisteredEasyBars[description] = { };
	end
	if ( self.RegisteredEasyBars[description].sortindex == nil ) then
		self.RegisteredEasyBars[description].barname = barname;
		self.RegisteredEasyBars[description].callback = callback;
		self.RegisteredEasyBars[description].sortindex = self.registeredBars;
		self.RegisteredEasyBars[description].disableAutoCreate = disable;
		self.registeredBars = self.registeredBars + 1;
	end
end

function ConfigurationHelper:ConstructBars()
	for key, value in pairs (self.RegisteredEasyBars) do
		if ( value.disableAutoCreate == nil ) then
			value.callback();
		end
	end
end

function ConfigurationHelper:GetEasyBars()
	return self.RegisteredEasyBars;
end

function ConfigurationHelper:SetPlayerLevel( newLevel )
	self.level = newLevel;
end

-- Create Quickslot Bar                           Name -      Rows - Columns - X coord - Y coord
function ConfigurationHelper:CreateBar( override, name, level, rows, columns, x, y, barType )
	if ( barType == nil ) then
		barType = QUICKSLOTBAR;
	end
	if ( level == nil or self.level >= level or override ~= nil ) then
		local foundbar = nil;
		for key, value in pairs (theSettingsManager:GetBars()) do
			if ( value.barName == name ) then
				foundbar = key;
			end
		end
		local theSettings = theSettingsManager:GetSettings();
		local autoBarID, autoBarSettings;
		if ( theSettings.autoCreatedBars ~= nil ) then
			for key, value in pairs (theSettings.autoCreatedBars) do
				if ( value.barName == name ) then
					autoBarID = key;
					autoBarSettings = value;
				end
			end
		end
		if ( override == true and foundbar ~= nil ) then
			if ( theSettings.autoCreatedBars ~= nil and theSettings.autoCreatedBars[ foundbar ] ~= nil ) then
				maitre_d:Remove( foundbar );
				foundbar = nil;
			end
		end
		if ( override ~= nil or ( autoBarID == nil and foundbar == nil ) ) then
			self.barid = maitre_d:Add( barType, autoBarID );
			self.barSettings = theSettingsManager:GetBarSettings( self.barid );
			if ( theSettings.autoCreatedBars == nil ) then
				theSettings.autoCreatedBars = { };
			end
			if ( theSettings.autoCreatedBars[self.barid] == nil ) then
				theSettings.autoCreatedBars[self.barid] = { };
			end
			theSettings.autoCreatedBars[self.barid].barName = name;

			self.barSettings.barName = name;
			if ( rows ~= nil ) then
				self.barSettings.quickslotRows = rows;
			end
			if ( columns ~= nil ) then
				self.barSettings.quickslotColumns = columns;
			end
			if ( rows ~= nil and columns ~= nil ) then
				self.barSettings.quickslotCount = rows * columns;
			end
			self.barSettings.x = x;
			self.barSettings.y = y;
		else
			self.barid = foundbar;
			self.barSettings = theSettingsManager:GetBarSettings( self.barid );
		end
		if ( menu ~= nil ) then
			theSettings = theSettingsManager:GetSettings();
			local mode = theSettings.barMode;
		
			menu:RegenerateEasyBarsMenu();
		
			theSettings = theSettingsManager:GetSettings();
			theSettings.barMode = mode;
		end
	else
		self.barid = nil;
	end
end

function ConfigurationHelper:SetBar( barid )
	if ( barid ~= nil ) then
		self.barid = barid;
		self.barSettings = theSettingsManager:GetBarSettings( barid );
		return self.barSettings;
	end
end

-- Set it to trigger on health                Bar ID - When to trigger
function ConfigurationHelper:SetTrigger( statType, percent )
	if ( self.barid ~= nil ) then
		if ( self.barSettings.events == nil ) then
			self.barSettings.events = { };
		end
		if ( self.barSettings.events.categories == nil ) then
			self.barSettings.events.categories = { };
		end

		self.barSettings.visible = false;

		if ( statType == ConfigurationHelper.HEALTH ) then
			self.barSettings.events.displayOnHealth = true;
			self.barSettings.events.healthTrigger = (percent / 100);
		elseif ( statType == ConfigurationHelper.POWER ) then
			self.barSettings.events.displayOnPower = true;
			self.barSettings.events.powerTrigger = (percent / 100);

		elseif ( statType == Turbine.Gameplay.EffectCategory.Disease ) then
			self.barSettings.events.categories[statType] = true;
		elseif ( statType == Turbine.Gameplay.EffectCategory.Fear ) then
			self.barSettings.events.categories[statType] = true;
		elseif ( statType == Turbine.Gameplay.EffectCategory.Poison ) then
			self.barSettings.events.categories[statType] = true;
		elseif ( statType == Turbine.Gameplay.EffectCategory.Wound ) then
			self.barSettings.events.categories[statType] = true;

		elseif ( statType == ConfigurationHelper.CTRL ) then
			self.barSettings.events.isControl = true;
		elseif ( statType == ConfigurationHelper.ALT ) then
			self.barSettings.events.isAlt = true;
		elseif ( statType == ConfigurationHelper.SHIFT ) then
			self.barSettings.events.isShift = true;
		end
	end
end

-- Set it to trigger on Buff                 
function ConfigurationHelper:SetBuffTriggerOptions( whenActive, Anding )
	if ( self.barid ~= nil ) then
		if ( self.barSettings.events == nil ) then
			self.barSettings.events = { };
		end
		self.barSettings.visible = false;
		self.barSettings.events.triggerOnClassBuffActive = whenActive;
		if ( Anding ) then
			self.barSettings.events.triggerBuffType = "and";
		else
			self.barSettings.events.triggerBuffType = "or";
		end
	end
end

-- Set it to trigger on Buff                Bar ID - When to trigger
function ConfigurationHelper:SetBuffTrigger( buff )
	if ( self.barid ~= nil ) then
		if ( self.barSettings.events == nil ) then
			self.barSettings.events = { };
		end
		if ( self.barSettings.events.effects == nil ) then
			self.barSettings.events.effects = { };
		end
		if ( theLocalizer:GetLanguage() ~= "en" ) then
			local events = eventManager:GetRegisteredEvents();
			for key, value in pairs (events.classes[playerClass].effects) do
				if ( value.englishSkillName == buff and self.barSettings.events.effects[buff] == nil) then
					self.barSettings.events.effects[key] = true;	
				end
			end
		else
			if ( self.barSettings.events.effects[buff] == nil ) then
				self.barSettings.events.effects[buff] = true;
			end
		end
	end
end

-- Set it to trigger on name                Bar ID - When to trigger
function ConfigurationHelper:SetClassRangeTrigger( name, theMin, theMax )
	if ( self.barid ~= nil ) then
		if ( self.barSettings.events == nil ) then
			self.barSettings.events = { };
		end
		if ( self.barSettings.events.classRange == nil ) then
			self.barSettings.events.classRange = { };
		end
		if ( self.barSettings.events.classRange[name] == nil ) then
			self.barSettings.events.classRange[name] = { };
			self.barSettings.events.classRange[name].minValue = theMin;
			self.barSettings.events.classRange[name].maxValue = theMax;
		end
	end
end

--                                       Bar ID  a  r  g  b
function ConfigurationHelper:SetBGColor( a, r, g, b )
	if ( self.barid ~= nil ) then
		self.barSettings.useBackgroundColor = true;
		self.barSettings.opacity = a;
		self.barSettings.backgroundColorRed = r;
		self.barSettings.backgroundColorGreen = g;
		self.barSettings.backgroundColorBlue = b;
	end
end

--                               Bar ID - Location - Hex for Shortcut
function ConfigurationHelper:AddShortcut( location, sData, sType, level )
	if ( self.barid ~= nil and (level == nil or self.level >= level) ) then
		if ( self.barSettings.quickslots == nil ) then
			self.barSettings.quickslots = { };
		end
		if ( self.barSettings.quickslots[location] == nil ) then
			self.barSettings.quickslots[location] = { };
		end
		if ( self.barSettings.quickslots[location].Data == nil ) then
			self.barSettings.quickslots[location].Data = sData;
			self.barSettings.quickslots[location].Type = sType;
		end
	end
end

--                               Bar ID - Location - Hex for Shortcut
function ConfigurationHelper:SetInventoryFilter( filter )
	if ( self.barid ~= nil ) then
		if ( self.barSettings.events == nil ) then
			self.barSettings.events = { };
		end
		if ( self.barSettings.events.inventory == nil ) then
			self.barSettings.events.inventory = { };
		end
		if ( self.barSettings.events.inventory.nameFilters == nil ) then
			self.barSettings.events.inventory.nameFilters = { };
		end
		self.barSettings.events.inventory.nameFilters[ filter ] = true;
	end
end

function ConfigurationHelper:Save()
	if ( self.barid ~= nil and maitre_d  ~= nil and maitre_d:Alive( self.barid )) then
		theSettingsManager:SetBarSettings( self.barid, self.barSettings );
	end
end