-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";
import "Tonic.UI.CheckBox";
import "Tonic.UI.ComboBox";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";

buttonWidth = 90;
selectionWidth = 160;
selectionHeight = 20;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

GeneralMenu = class( Tonic.UI.AutoListBox );

function GeneralMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );

	self.utils = Tonic.UI.MenuUtils();

	self.settingsBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.GeneralMenu["General Settings"]);
	
	if ( realClassSet == nil ) then
		self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["Plugin can't determine your class, please select the correct one:"], selectionWidth + 200, selectionHeight + 10 );
		
		self.classList = Tonic.UI.ComboBox();
		self.classList:SetSize( 200, 20 );
		self.classList:SetParent( self.settingsBox );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Guardian"], 		23 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Captain"], 		24 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Minstrel"], 		31 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Burglar"], 		40 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Hunter"], 		162 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Champion"], 		172 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Lore Master"], 	185 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Rune Keeper"], 	193 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Warden"], 		194 );
		self.settingsBox:AddItem( self.classList );
	end
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["If you want to copy your bar locations from another character on this server you can perform that by selecting the characters name from the dropdown and selecting 'Copy Profile'."], selectionWidth + 250, selectionHeight + 40 );

	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.GeneralMenu["Languages"]);
	
	self.languageList = Tonic.UI.ComboBox();
	self.languageList:SetSize( 200, 20 );
	self.languageList:SetParent( self.settingsBox );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["English"], "en" );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["German"], "de" );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["French"], "fr" );
	self.settingsBox:AddItem( self.languageList );
	
	self:AddSettings();
	self:AddCommandsBar();
	
	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.sidebar:SetParent( self.settingsBox );
	self.sidebar:SetSize( 8, 450 );
	self.sidebar:SetPosition( windowWidth - selectionWidth - 5, 0 );
	self.sidebar:SetZOrder(60);
	self.settingsBox:SetVerticalScrollBar( self.sidebar );

	self.settingsBox:SetSize( windowWidth - selectionWidth + 5, 500 );
	self:SetSize( windowWidth - selectionWidth + 25, 500 );
		
	self:AddItem( self.settingsBox );
end

function GeneralMenu:AddSettings()
	self.utils:AddLabelBox( self.settingsBox, "", 0, 15 );
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.GeneralMenu["Copy Profiles"]);
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["Profiles"], selectionWidth + 200, selectionHeight + 25 );

	self.profileList = Tonic.UI.ComboBox();
	self.profileList:SetSize( 200, 20 );
	self.profileList:SetParent( self.settingsBox );
	self.settingsBox:AddItem( self.profileList );
	
	self.utils:AddLabelBox( self.settingsBox, "", 0, 15 );
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["Take"], selectionWidth + 200, selectionHeight );

	self.theirBarList = Tonic.UI.ComboBox();
	self.theirBarList:SetSize( 200, 20 );
	self.theirBarList:SetParent( self.settingsBox );
	self.settingsBox:AddItem( self.theirBarList );

	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["Give"], selectionWidth + 200, selectionHeight );
	self.myBarList = Tonic.UI.ComboBox();
	self.myBarList:SetSize( 200, 20 );
	self.myBarList:SetParent( self.settingsBox );
	self.settingsBox:AddItem( self.myBarList );

	local box1 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal );	
	local noShortcutButton = Turbine.UI.Lotro.Button();
	noShortcutButton:SetText( LOCALESTRINGS.GeneralMenu["Without Icons"] );
	noShortcutButton:SetSize( buttonWidth + 75, selectionHeight );
	noShortcutButton.MouseClick = function( sender, args )
		local profile = self.profileList:GetSelection();
		local theirBar = self.theirBarList:GetSelection();
		local myBar = self.myBarList:GetSelection();
		if ( profile ~= nil and theirBar ~= nil and theirBar ~= "" ) then
			theSettingsManager:CopyProfile( profile, theSettingsManager.PARTIAL, theirBar, false );
		elseif ( profile ~= nil and myBar ~= nil and myBar ~= "" ) then
			self.utils:AddLabelBox( self.settingsBox, "", 0, 15 );
			theSettingsManager:CopyProfile( profile, theSettingsManager.PARTIAL, myBar, true );
		end
	end
	box1:AddItem( noShortcutButton );

	local shortcutButton = Turbine.UI.Lotro.Button();
	shortcutButton:SetText( LOCALESTRINGS.GeneralMenu["With Icons"] );
	shortcutButton:SetSize( buttonWidth + 75, selectionHeight );
	shortcutButton.MouseClick = function( sender, args )
		local profile = self.profileList:GetSelection();
		local theirBar = self.theirBarList:GetSelection();
		local myBar = self.myBarList:GetSelection();
		if ( profile ~= nil and theirBar ~= nil and theirBar ~= "" ) then
			theSettingsManager:CopyProfile( profile, theSettingsManager.ALL, theirBar, false );
		elseif ( profile ~= nil and myBar ~= nil and myBar ~= "" ) then
			theSettingsManager:CopyProfile( profile, theSettingsManager.ALL, myBar, true );
		end
	end
	box1:AddItem( shortcutButton );
	self.settingsBox:AddItem( box1 );
	
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.GeneralMenu["Display Launcher?"]);
	self.displayGobletCheckbox = self.utils:AddCheckBox( self.settingsBox, LOCALESTRINGS.GeneralMenu["Yes"], selectionWidth, selectionHeight + 50 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight + 100 );
end

function GeneralMenu:AddCommandsBar()
end

function GeneralMenu:DisplaySettings( showQuickslots )
	self.settingsBox:SetVisible( showQuickslots );
	
	local theSettings = theSettingsManager:GetWrapperSettings();
	
	self.displayGobletCheckbox.CheckedCallback = function( sender, args )
		local settings = theSettingsManager:GetWrapperSettings();
		settings.visible = self.displayGobletCheckbox.IsChecked;
		theSettingsManager:SetWrapperSettings( settings );

		wrapper:SetVisible( settings.visible );
	end
	self.displayGobletCheckbox:SetChecked( theSettings.visible );

	if ( realClassSet == nil ) then
		self.classList.SelectedIndexChanged = function(sender, args)
			local settings = theSettingsManager:GetSettings();
			if ( settings.playerClass ~= self.classList:GetSelection() ) then
				settings.playerClass = self.classList:GetSelection();
				playerClass = self.classList:GetSelection();
				theSettingsManager:SaveSettings();
				menu:RegenerateQuickslotsMenu();
				--menu = Tonic.TonicBars.Menu.MainMenu( theSettingsManager, maitre_d );
			end
		end
		theSettings = theSettingsManager:GetSettings();
		self.classList:SetSelection( theSettings.playerClass );
	end

	self.languageList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.menuLanguage = self.languageList:GetSelection();
		theSettingsManager:SaveSettings();
	end

	self.profileList.SelectedIndexChanged = function(sender, args)
		self:RefreshTheirProfileBars();
		self:ChangeProfileVisibilty();
	end
	self.myBarList.SelectedIndexChanged = function(sender, args)
		if ( self.myBarList:GetSelection() == "" ) then
			self:RefreshTheirProfileBars();
		else
			self.theirBarList:Clear();
		end
	end
	self.theirBarList.SelectedIndexChanged = function(sender, args)
		if ( self.theirBarList:GetSelection() == "" ) then
			self:RefreshMyProfileBars();
		else
			self.myBarList:Clear();
		end
	end
end

function GeneralMenu:GetSelection()
	return nil;
end

function GeneralMenu:ChangeProfileVisibilty()
	if ( self.profileList:GetSelection() == nil or self.profileList:GetSelection() == "" ) then
		self.myBarList:SetVisible( false );
		self.theirBarList:SetVisible( false );		
	else
		self.myBarList:SetVisible( true );
		self.theirBarList:SetVisible( true );
	end 
end

function GeneralMenu:RefreshComboBox()
	self.profileList:Clear();
	for key, value in opairs (theSettingsManager:GetProfiles() ) do
		local found = false;
		if ( player:GetName() == key ) then
			found = true;
		end
		for i = 1, self.profileList:GetItemCount() do
			if ( self.profileList:GetItem(i) == key ) then
				found = true;
			end
		end
		if ( found == false ) then
			self.profileList:AddItem( key, key );
		end
	end
	self:RefreshMyProfileBars();
end

function GeneralMenu:RefreshTheirProfileBars()
	self.theirBarList:Clear();
	self.theirBarList:AddItem( "", "" );
	for key, value in opairs (theSettingsManager:GetProfileBars(self.profileList:GetSelection()) ) do
		local found = false;
		if ( player:GetName() == key ) then
			found = true;
		end
		for i = 1, self.theirBarList:GetItemCount() do
			if ( self.theirBarList:GetItem(i) == key ) then
				found = true;
			end
		end
		if ( found == false ) then
			if ( value.barName ~= nil and value.barName ~= "" ) then
				self.theirBarList:AddItem( self:AppendBarType( value.barType, value.barName ) , key );
			else
				self.theirBarList:AddItem( self:AppendBarType( value.barType, key ), key );
			end
		end
	end
end

function GeneralMenu:RefreshMyProfileBars()
	self.myBarList:Clear();
	self.myBarList:AddItem( "", "" );
	for key, value in opairs (theSettingsManager:GetBars() ) do
		local found = false;
		if ( player:GetName() == key ) then
			found = true;
		end
		for i = 1, self.myBarList:GetItemCount() do
			if ( self.myBarList:GetItem(i) == key ) then
				found = true;
			end
		end
		if ( found == false ) then
			if ( value.barName ~= nil and value.barName ~= "" ) then
				self.myBarList:AddItem( self:AppendBarType( value.barType, value.barName ) , key );
			else
				self.myBarList:AddItem( self:AppendBarType( value.barType, key ), key );
			end
		end
	end
end

function GeneralMenu:AppendBarType( type, value )
	local name;
	if ( type == QUICKSLOTBAR) then
		name = value .. " (Quick)"
	elseif ( type == EXTENSIONBAR) then
		name = value .. " (Ext)"
	else
		name = value .. " (Inv)"
	end
	return name
end
